#
# spec file for package sysstat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sysstat
Version:        12.7.5
Release:        2.5
Summary:        Sar and Iostat Commands for Linux
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/sysstat/sysstat
Source:         https://github.com/sysstat/sysstat/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        isag.desktop
# PATCH-FIX-OPENSUSE should be upstreamed
# add locking to scripts sa1 and sa2 (bnc#7861)
Patch0:         sysstat-8.1.6-sa1sa2lock.diff
# PATCH-FIX-OPENSUSE should be upstreamed
# use getpagesize() instead of kb_shift for hugetable archs
Patch2:         sysstat-8.0.4-pagesize.diff
# PATCH-FIX-OPENSUSE bsc#1151453
Patch3:         sysstat-service.patch
Patch4:         harden_sysstat.service.patch
BuildRequires:  findutils
BuildRequires:  gettext-runtime
BuildRequires:  libpcp-devel
BuildRequires:  libpcp_import1
BuildRequires:  pkgconfig
BuildRequires:  sed
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
Requires:       util-linux
Requires:       xz
%{?systemd_ordering}
%ifnarch s390 s390x
BuildRequires:  libsensors4-devel
%endif

%description
Sar and Iostat commands for Linux. The sar command collects and reports
system activity information. The iostat command reports CPU statistics
and I/O statistics for TTY devices and disks.  The information
collected by sar and iostat can be saved in a binary file for future
inspection. Both commands now support SMP machines when displaying CPU
utilization.

%package isag
Summary:        Interactive System Activity Grapher for sysstat
Group:          System/Monitoring
Requires:       gnuplot
Requires:       sysstat = %{version}
Requires:       tk

%description isag
This package includes the isag command, which graphically displays the
system activity data stored in a binary data produced by a sar command
from a sysstat package.

%prep
%autosetup -p1
cp %{SOURCE1} .
# remove date and time from objects
find ./ -name \*.c -exec sed -i -e 's: " compiled " __DATE__ " " __TIME__::g' {} \;

%build
export conf_dir="%{_sysconfdir}/sysstat"
export sa_lib_dir="%{_libdir}/sa"
export cron_owner=root
export LFLAGS="-L. -lsyscom"
export history="60"
export sadc_options="-S ALL"
%configure \
           --with-systemdsystemunitdir=%{_unitdir} \
           --with-systemdsleepdir=%{_systemd_util_dir}/system-sleep \
           --enable-install-cron \
           --disable-silent-rules \
           --enable-nls \
           --disable-man-group \
           --enable-copy-only \
           --disable-file-attr \
           --enable-debug-info \
           --enable-pcp \
%ifnarch s390 s390x
           --enable-sensors \
%endif
           --disable-stripping
%make_build

%install
mkdir -p %{buildroot}%{_localstatedir}/log/sa %{buildroot}%{_sbindir}
%make_install
install -D -m 0644 isag.desktop %{buildroot}%{_datadir}/applications/isag.desktop
%suse_update_desktop_file isag
cp contrib/isag/isag %{buildroot}%{_bindir}
cp contrib/isag/isag.1 %{buildroot}%{_mandir}/man1
rm -rf %{buildroot}%{_datadir}/doc/sysstat*
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcsysstat
%find_lang %{name}

%check
# Newer versions only have simulation tests
# make %%{?_smp_mflags} test

%pre
%service_add_pre sysstat.service sysstat-collect.service sysstat-collect.timer sysstat-summary.service sysstat-summary.timer sysstat-rotate.service syssstat-rotate.timer

%post
%service_add_post sysstat.service sysstat-collect.service sysstat-collect.timer sysstat-summary.service sysstat-summary.timer sysstat-rotate.service syssstat-rotate.timer
# Earlier versions used cron, remove leftover
rm -f /etc/cron.d/sysstat || :

%preun
%service_del_preun sysstat.service sysstat-collect.service sysstat-collect.timer sysstat-summary.service sysstat-summary.timer sysstat-rotate.service syssstat-rotate.timer
[ "$1" -gt 0 ] || rm -rf %{_localstatedir}/log/sa/*

%postun
%service_del_postun sysstat.service sysstat-collect.service sysstat-collect.timer sysstat-summary.service sysstat-summary.timer sysstat-rotate.service syssstat-rotate.timer

%files -f "%{name}.lang"
%license COPYING
%doc CHANGES CREDITS FAQ.md README.md
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%exclude %{_mandir}/man1/isag*
%dir %{_sysconfdir}/sysstat
%dir %{_systemd_util_dir}/system-sleep
%config(noreplace) %{_sysconfdir}/sysstat/sysstat
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/sysstat/sysstat.ioconf
%{_bindir}/cifsiostat
%{_bindir}/iostat
%{_bindir}/mpstat
%{_bindir}/pidstat
%{_bindir}/sadf
%{_bindir}/sar
%{_bindir}/tapestat
%exclude %{_bindir}/isag
%{_libdir}/sa
%{_unitdir}/sysstat.service
%{_unitdir}/sysstat-collect.service
%{_unitdir}/sysstat-collect.timer
%{_unitdir}/sysstat-summary.service
%{_unitdir}/sysstat-summary.timer
%{_unitdir}/sysstat-rotate.service
%{_unitdir}/sysstat-rotate.timer
%{_systemd_util_dir}/system-sleep/sysstat.sleep
%dir %{_localstatedir}/log/sa
%{_sbindir}/rcsysstat

%files isag
%doc contrib/isag/README-isag
%{_mandir}/man1/isag*
%{_bindir}/isag
%{_datadir}/applications/isag.desktop

%changelog
* Thu Aug  8 2024 Johannes Segitz <jsegitz@suse.com>
- Updated sysstat-8.1.6-sa1sa2lock.diff to use flock to create the
  lockfile. Using lockfile would require additional SELinux permissions.
  Require util-linux instead of procmail for this (bsc#1228246)
* Fri Jun  7 2024 pgajdos@suse.com
- version update to 12.7.5
  2023/12/17: Version 12.7.5 - Sebastien Godard (sysstat <at> orange.fr)
  * [Quan quan Cao]: sar/sadc: Add new metrics pgprom/s and pgdem/s.
  * sar: Remove %%vmeff metric.
  * sadf: Update various output formats to take into account metrics
  that have been added or removed.
  * Update DTD and XSD documents.
  * Update sar manual page.
  * sar: Add a cron entry and a new systemd service and timer to rotate
  daily data file at midnight.
  * Option -V with sysstat commands also displays environment contents.
  * [Sam Morris]: Use correct encoding to produce hyphen-minus when
  rendering man pages.
  * Add UMASK variable definition to sysstat(5) manual page.
  * Update non regression tests.
  * Add --getenv option to commands that didn't have it.
  * Update README file for Debian-based distros.
  * Update link to my personal web page in README and manual pages.
  * NLS: Translations updated.
  2023/06/18: Version 12.7.4 - Sebastien Godard (sysstat <at> orange.fr)
  * Makefile.in: Fix installation error.
  * Makefile.in: Remove gcc warning displayed in LTO mode.
  2023/06/16: Version 12.7.3 - Sebastien Godard (sysstat <at> orange.fr)
  * sar: Add new option '-x' used to display extended reports.
  * [Pavel Kopylov]: Fix an overflow which is still possible for
  some values.
  * [Jan Kurik]: Fix export of PSI metrics to a PCP archive.
  * [Lukáš Zaoral]: Tools that take `--dec=X` option should only accept
  digits.
  * common.c: Fix an overflow which was still possible for some values.
  * iostat: Try to avoid displaying negative values.
  * Free pointer if realloc() fails.
  * Don't check if unsigned expressions are less than zero.
  * Declare parameters with "const" when possible.
  * Remove conditions which are always true.
  * Reduce variables scope when relevant.
  * Don't assign values that are never used.
  * Fix types used in format strings.
  * Split large functions into smaller ones.
  * Specify field width when using sscanf() function.
  * search_list_item(): Return position in list instead of a boolean.
  * add_list_item(): Also return item position in list.
  * svg_stats.c: Ignore negative values for fields position.
  * svg_stats.c: Reuse buffers pointers definition.
  * svg_stats.c: Reuse intermediate calculations.
  * svg_stats.c: Don't repeat test on DISPLAY_CPU_DEF().
  * sa_common.c: Don't use (void *) pointer in calculation.
  * iostat.c: Clarify calculation precedence for '+' and '?'.
  * sar/sadf: Refactor buffer allocation functions.
  * sar/sadf: Add a check on file's records header data.
  * sar/sadf: Stop when invalid data are read in records header.
  * sar/sadf: Check upper bounds of value read from file.
  * sadf_misc.c: Fix indentation in code.
  * activity.c: Init item_list even for other commands than sadf.
  * sa_conv.c: Reallocate buffers only when needed.
  * sa_conv.c: Fix untrusted allocation size.
  * pr_stats.c: Remove some dead code.
  * sar.c: Make sure buffer is null terminated.
  * do_test: Add several new options.
  * do_test: Don't strip binaries when in TEST mode.
  * Update non regression tests.
  * simtest: Change default _unix_time value.
  * Makefile.in: Simplify dependencies.
  * Makefile_in: Small update made to copyyear target.
  * sadf: XML: Update DTD and XSD documents.
  * sadf: XML: Remove references to my personal web site.
  * Restore mode for iconfig file.
  * Fix typo in sar's manual page. Sar manual page updated.
  * Other manual pages updated.
  2023/01/29: Version 12.7.2 - Sebastien Godard (sysstat <at> orange.fr)
  * All commands: Avoid displaying healthy metrics values in "red".
  * sar/sadf: Add new activity: Battery statistics (A_PWR_BAT).
  * [Kevin Stubbings]: Add CodeQL workflow.
  * sar: Make sure timestamps are always displayed in local time.
  * sar/sadf: Starting and ending times used with options -s/-e can now
  be entered as a number of seconds since the epoch.
  * sar/sadf: Strengthen tests made on arguments given to options -s/-e.
  * sadf: PCP: Fix pmiID used for two USB metrics [12.6.2].
  * [Nathanael P Wilson]: sadf: Fix extra space when no TZ printed.
  * sadc: Add another overflow check [12.6.2].
  * DTD and XSD documents updated.
  * Makefile: Fix dependencies.
  * NLS translations updated. New Belarusian translation added.
  * Remove LGTM links from README file.
  * Manual pages updated.
  * Non regression tests updated.
  2022/11/06: Version 12.7.1 - Sebastien Godard (sysstat <at> orange.fr)
  * Fix possible overflow in sa_common.c (GHSL-2022-074) [12.6.1].
  * sadf: Add support for option -t with SVG output to make it possible
  to display timestamps in the same locale as that of the file creator.
  * sadf: Print timezone instead of UTC in true time mode. Timezone is
  also displayed in local time.
  * sadf: PCP: Fix timestamps written to PCP archive file.
  * sar: Add new environment variable S_REPEAT_HEADER.
  * pidstat: Return exit code of the process that was monitored with option
  - e.
  * mpstat: Add option -H to handle vCPU physical hotplug.
  * Add local, xlocal and debug targets to iconfig script.
  * Turn off gcc's tree-slp-vectorize option which was making sadf crash
  in some situations.
  * sa_conv.c: Make size of statistics structures from older sysstat
  versions immutable [12.6.1].
  * [Bernhard M. Wiedemann]: Declare sadc dependency on libsyscom.a
  [12.6.1].
  * [Steve Kay]: Fix gcc v11.2 warnings [12.6.1].
  * [Steve Kay]: Various cosmetic fixes [12.6.1].
  * [Jan Christoph Uhde]: sar: Remove `-I int_list` from man-page and
  help [12.6.1].
  * [Frank Dana]: Consolidate systemctl commands in README file [12.6.1].
  * [Rong Tao]: Remove whitespace characters at the end of lines
  [12.6.1].
  * Update configure file to deal with newer autoconf version. configure.in
  file is renamed to configure.ac.
  * Update DTD and XSD documents.
  * sar and sysstat manual pages updated.
  * NLS updated. Add new Georgian translation.
  * Non regression tests updated.
- modified patches
  %% sysstat-8.0.4-pagesize.diff (refreshed)
  %% sysstat-8.1.6-sa1sa2lock.diff (refreshed)
- deleted patches
  - sysstat-CVE-2023-33204.patch (upstreamed)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Jul 18 2023 Franck Bui <fbui@suse.com>
- Drop the build dependency on systemd. This was not really necessary and it
  decreases the number of build deps from 207 to 189.
* Tue May 23 2023 David Anes <david.anes@suse.com>
- Security fix: (CVE-2023-33204, bsc#1211507)
  * Fix an overflow which is still possible for some values.
  * Added patch sysstat-CVE-2023-33204.patch
* Fri Apr 14 2023 David Anes <david.anes@suse.com>
- Update to version 12.6.2:
  * sadf: PCP: Fix pmiID used for two USB metrics.
  * sadc: Add another overflow check.
* Fri Nov 11 2022 David Anes <david.anes@suse.com>
- Update to version 12.6.1:
  * Fix possible overflow in sa_common.c
    (CVE-2022-39377, GHSL-2022-074, boo#1205224)
  * sa_conv.c: Make size of statistics structures from older sysstat
    versions immutable.
  * Declare sadc dependency on libsyscom.a.
  * Fix gcc v11.2 warnings.
  * Various cosmetic fixes.
    sar: Remove `-I int_list` from man-page and help.
  * Consolidate systemctl commands in README file.
  * Remove whitespace characters at the end of lines.
* Thu Sep 15 2022 David Anes <david.anes@suse.com>
- Add support for PCP (Performance Co-Pilot). [bsc#1203065]
* Mon May 30 2022 David Anes <david.anes@suse.com>
- Rebased patches:
  * sysstat-8.1.6-sa1sa2lock.diff
- Update to 12.6.0:
  * sar: Fix maximum value for A_IRQ activity.
  * sar/sadf: A_NET_SOFT: Add new metric softnet network backlog.
  * sadc: A_NET_SOFT: Use CPU id from /proc/net/softnet_stat.
  * Update DTD and XSD documents (softnet backlog).
  * sar/sadf: Convert 64-bit time value to time_t as needed.
  * sadf: Add basic colorization to sadf's output.
  * sadf: Add sanity checks on values read from file.
  * sadf: PCP: Fix multiple metrics name problems.
  * sa_common.c: Remove unneeded variable assignment.
  * Take into account LDFLAGS passer to configure script.
  * Various janitorial fixes and updated.
  * Update FAQ.
  * Update sar manual page.
  * Update NLS translations.
  * Update non regression tests..
* Fri Mar 11 2022 David Anes <david.anes@suse.com>
- fix changelog typos.
- update to 12.4.5:
  * sar/sadf: Make sure that datafiles with unknown activities can
    be read by sar and sadf.
  * sar/sadf: Don't reallocate buffers for activities not present
    in file.
  * sar: Make sure that all buffers are copied in copy_structures()
    function.
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 12.4.4:
  * iostat: Always display persistent names with option -j.
  * iostat: Fix how device mapper names are taken into account when
    entered on the command line.
  * mpstat: Don't display offline CPU.
  * mpstat: Fix values displayed when an offline CPU goes back online.
  * mpstat: Fix untrusted loop bound.
  * mpstat: Update non regression tests.
  * Use `grep -E` instead of deprecated `egrep`.
  * Spelling and grammar fixes.
  * Update man pages with correct spelling of "JavaScript".
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_sysstat.service.patch
* Sun Oct  3 2021 Christian Boltz <suse-beta@cboltz.de>
- drop sysstat-disable-test-failures.patch - tests are fine on s390x
  and ppc64, no need to ignore test failures anymore
* Fri Jun  4 2021 Dirk Müller <dmueller@suse.com>
- remove stale symlink to cronfile on update
* Thu Feb 18 2021 Dirk Müller <dmueller@suse.com>
- update to 12.4.3:
  * sar: Fix return code sent by write_stats() function.
  * sar/sadc: Dereference nr array pointer in struct activity.
  * sadf: SVG: Make graphs discontinuous for disconnected devices.
  * sadf: SVG: Fix inadequate discontinuities in some graphs.
  * sadf: SVG: Use the <count> parameter entered on the command line.
  * sar/sadc/sadf: Check untrusted values before use.
  * sar/sadc: Don't use IFNAMSIZ value from <net/if.h>.
  * Makefile: Define TEST flag when making simulation tests.
  * Non regression tests results updated.
  * Update NLS translations.
* Fri Jan 29 2021 Dirk Müller <dmueller@suse.com>
- update to 12.4.2:
  * [Aleksei Nikiforov]: Fix alignment and structure size for 32-bit
  systems.
  * Fix metric's name in sar -y output: txmtin -> xmtin.
  * FAQ: Add links to markdown file.
  * [Tim Gates]: sar.c: Fix typo in comment.
  * NLS updated.
  * [Petr Pavlu]: Workaround for iowait being decremented.
  * [SacValleyTech]: Make sure setbuf() is the first operation
  performed on stream.
  * [Michal Berger]: Fix typo in PHYS_PACK_ID definition.
  * configure: Fix option --disable-compress-manpg.
  * sar: Update definition for runq-sz metric in manual page.
  * iostat: Update manual page (explain "*_w+d*" fields).
  * iostat: Explain options -f/+f in manual page.
  * [Nan Xiao]: mpstat: Add -T option in help message.
  * [Nan Xiao]: mpstat: Fix typo in manual page.
  * FAQ.md file: Add missing spaces at end of line.
  * Non regression tests updated.
  * NLS updated.
- drop sysstat-iowait-decr.patch (upstream)
* Sat Oct  3 2020 Thorsten Kukuk <kukuk@suse.com>
- Don't hard require systemd, it works without,too. (bsc#1186827)
* Fri Sep 18 2020 Pedro Monreal <pmonreal@suse.com>
- Fix average iowait output of sar [bsc#1174227]
  * The iowait value reported by the kernel can also decrement as
    a result of inaccurate iowait tracking. Waiting on IO can be
    first accounted as iowait but then instead as idle. Therefore
    if the idle value during the same period did not decrease then
    consider this is a problem with the iowait reporting and correct
    the previous value according to the new reading. Otherwise, treat
    this as CPU coming back online.
- Add patch sysstat-iowait-decr.patch
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- update sysstat-8.1.6-sa1sa2lock.diff: also remove locking on
  sleep/resume (bsc#1175913)
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 12.4.0:
  * All commands: Display statistics in color by default when the
    output is connected to a terminal.
  * sar: Now pretty-print all device names by default (that is to
    say, you no longer need to use option -p with option -d for that).
  * cifsiostat, iostat, sar: Add new --pretty option (this option
    makes the reports easier to read when long item names are used).
  * iostat: No longer use sysstat.ioconf file to determine the name
    of the devices. This file gave a wrong name for some devices
    with big minor numbers.
  * iostat, sar: Make device name consistent between both of them.
  * configure: Add new option "--enable-use-crond" to use standard
    cron daemon even if systemd is installed.
  * configure: Use AC_COMPILE_IFELSE instead of old AC_TRY_COMPILE
    macro. Remove other obsolete autoconf macros.
  * configure: Add new option "delay_range=". Used by sa2 script
    to wait for a random delay.
  * configure: Fix --enable-debuginfo option.
  * sa1: Insert a comment in daily datafile on system suspend/resume.
  * sa2: Wait for a random delay before running to prevent massive
    I/O burst on some systems.
  * sar: Fix typo in manual page.
  * sar, iostat, cifsiostat, mpstat, pidstat, tapestat and sa1 manual
    pages updated.
  * Update style for all manual pages.
  * Compress manual pages by default when they are installed.
  * Makefile: Remove all reports and date files (even those compressed
    with another program than gzip) when told to do so.
  * Add pcp help file to be used with iconfig script.
  * Update Travis script (now calls do_test script).
  * sadf: Output format which doesn't accept the use of option -T
    should not also reject the use of option -t [12.2.3].
  * [Tom Hebb]: Replace index() call with strchr() call [12.2.3].
  * Use NULL as an argument for time(2) system call [12.2.3].
  * Various cosmetic changes in code (comments updated, dead code
    removed, etc.)
  * NLS updated.
  * Non regression environment updated. New tests added.
  * Better handle big minor numbers in sysstat test code.
  * Fix gcc V10 warnings in sysstat 12.0.1 code used for test.
* Wed May 13 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 12.3.3:
  * sar/sadc: Add new Pressure-Stall Information (PSI) statistics.
  * sadf: Add support for PSI statistics.
  * iostat: Add support for devices managed by userspace drivers (e.g. spdk).
    Add new flags -f/+f to specify an alternate location for stats files.
  * sar: Don't display duplicate entries in /etc/mtab [12.2.2].
  * sar: Don't display "Inconsistent input data" error message when no
    activities are collected by sadc.
  * sadf: XML: Remove "per" attribute for memory activity.
  * sadf: Add new option "hz=" for datafile conversion.
  * Various updates to remove GCC v9/v10 warnings.
  * sar: Don't check if we are close enough to selected interval when
    interval=1 [12.2.2].
  * sadf: Use actual number of items, not its pointer address [12.2.2].
  * [Sdrkun]: sa1: Create default sa directory if it doesn't exist [12.2.2].
  * pr_stats.c: Printing timestamp should appear only once [12.2.2].
  * common.c: Remove unused get_dev_part_nr() function [12.2.2].
  * DTD and XSD documents updated.
  * sar and sadf manual pages updated.
  * Non regression tests updated. New tests added (sar, iostat).
  * pidstat: Major code refactoring. Several bugs fixed.
  * pidstat: Don't display unneeded spaces following command name
    when option -l is used.
  * cifsiostat: Major code refactoring.
  * simtest: Add test environment for pidstat command.
  * simtest: Add new non regression tests for iostat command.
  * pidstat: Remove extra space at end of command name [12.2.2].
  * [Anatoly Pugachev]: Fix sa2 script, so it wont complain on empty list
    for compress program [12.2.2].
  * iostat: Make sure pointer on linked list is initialized [12.2.2].
  * [Fabrice Fontaine]: Makefile: Link with -lintl if needed [12.2.2].
  * NLS translation updated.
* Tue Jan 21 2020 Paolo Stivanin <info@paolostivanin.com>
- Version update to 12.3.1
  * [Konstantin Khlebnikov]: iostat: Add flush I/O statistics
    (statistics available starting with kernel 5.5).
  * mpstat: Add new switch to display system topology.
  * mpstat: Allow to select individual CPU/nodes with option -A.
  * cifsiostat: Add support for SMB2 version of statistics file.
  * mpstat: Add non regression tests.
  * tapestat: Add non regression tests.
  * cifsiostat: Add non regression tests.
  * iostat: Add new non regression tests.
  * sadf: Fix double free in check_file_actlst() [12.2.1].
  * sadf: Fix heap overflow in logic2_display_loop() function.
  * iostat: Fix wrong unit used in JSON output [12.2.1].
  * [Leo]: Add missing header files when using musl C library [12.2.1].
  * [Albert]: Add missing empty line in FAQ.md file [12.2.1].
  * mpstat and iostat manual pages updated.
  * Cosmetic changes.
- Remove sysstat-CVE-2019-19725.patch as it is no longer needed
* Thu Dec 12 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Security fix: [bsc#1159104, CVE-2019-19725]
  * Double free in check_file_actlst in sa_common.c
- Add sysstat-CVE-2019-19725.patch
- Rebase sysstat-disable-test-failures.patch
* Thu Nov 14 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Version update to 12.2.0
  * sar/sadc: Save timezone value in binary data files (saDD).
  * sadf: Display timezone value in output from sadf -H.
  * sar/sadf: Make sure we will always be able to read file headers
    structures from older versions.
  * sadf: Enhance raw format output (now also display records header contents).
  * sadf: Update DTD and XSD documents. Fix their contents so that XML
    output from 12.0.x sadf versions validates.
  * sar/sadf: Change 'flags' variable type from "unsigned int" to "uint64_t".
  * simtest: Make all tests independent from timezone value.
  * simtest: Add more non regression tests.
  * sadf: Small fix in manual page.
  * NLS updated.
  * FAQ updated.
- Remove patch fixed upstream:
  * sysstat-CVE-2019-16167.patch
* Thu Nov 14 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Version udate to 12.1.7
  * sar/sadc: Add stable identifier support for disks statistics.
  * sar/sadf: Add extra flexibility in binary data file in case of
    a future format change.
  * sadf: sadf -H output updated.
  * iostat: Fix several bugs (CID ##349502, #349503, #349500 and #349501).
  * sar: Manual page updated.
  * sadf: Fix memory corruption bug due to integer overflow in
    remap_struct() function (try #2).
  * configure: Add new configuration variables: conf_file and sar_dir.
  * simtest: sar: Add new non regression tests.
  * simtest: iostat: Make tests independent from timezone value.
  * NLS updated.
- Version update to 12.1.6
  * iostat: Major code refactoring. Devices structures are now
    dynamically allocated, better handle the case when devices are
    removed then inserted again in the system, better command line
    parsing, better handle devices with a slash in their name.
  * sar/sadf: Allow to select individual CPU and/or interrupts when option -A is used.
  * sar: Better handle the case when Fibre Channel hosts are added to the system.
  * sar: Fix sar -s/-e output on datafiles spanning two consecutive days.
  * sadf: Fix memory corruption bug due to integer overflow in remap_struct() function.
  * Update sysstat simulation test environment (new tests added, etc.)
  * sar manual page updated.
  * Various cosmetic fixes (comments updated in code, etc.)
  * NLS updated.
* Tue Nov  5 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Temporarily disable failing tests on s390x and ppc64 architectures
  * Add sysstat-disable-test-failures.patch
* Mon Nov  4 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Use upstream systemd service and timer files [bsc#1151453]
  * Add sysstat-service.patch
* Wed Oct 30 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Enable log information on service start/stop [bsc#1144923, jsc#SLE-5958]
* Tue Oct 29 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Migrate from cron to systemd timer units [bsc#1151453]
  * Add sysstat-collect.{service,timer} and sysstat-summary.{service,timer}
  * Remove sysstat.cron.suse
* Thu Oct 10 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Requires cron, since sysstat.service wants to create
  /etc/cron.d/sysstat link and /etc/cron.d/ is from cron package
* Tue Sep 10 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Security fix: [bsc#1150114, CVE-2019-16167]
  * Memory corruption due to an Integer Overflow in remap_struct()
    in sa_common.c
  * Added sysstat-CVE-2019-16167.patch
* Tue Aug 27 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Version update to 12.0.6
  * sadc: Check if InCsumErrors is present for EICMP as well.
  * sadf: XML: Fix bad transmission words statistics for Fibre Channel hosts.
  * iostat: Fix wrong CPU statistics displayed for the first sample when option -y is used.
  * iostat: Make sure UUID given on the command line is not taken as interval value.
  * Allow more space for persistent type directory names.
* Tue Jul 23 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Remove deprecated Require gettext and require gettext-runtime only
  during build [bsc#1142470]
* Fri May 31 2019 seanlew@opensuse.org
- Version update to 12.0.5
  * Complete support for PCP output formwat with sadf
  * Includes simulation/test environment to run non-regression tests
* Wed Jan 23 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Version update to 12.0.3
  * 2018/12/14: Version 12.0.3 - Sebastien Godard (sysstat<at>orange.fr)
  * sadf: Fix out of bound reads security issues (CVE-2018-19416
    and CVE-2018-19517).
  * sadf: Fix possible infinite loop.
  * [Todd Walton]: Clarify sadc manual page and FAQ on using
    multiple -S keywords.
  * Remove remap_struct() prototype from sa.h.
  * [Steve Kay]: Use memcpy rather than strncpy, in order to
    avoid truncation warning.
  * [Steve Kay]: Cosmetic fixes in configure file.
  * [Anatoly Pugachev]: Fix comment in sar.c.
- Dropped patch fixed upstream:
  * sysstat-12.0.2-CVE-2018-19416-and-CVE-2018-19517.patch
* Tue Nov 27 2018 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Security fixes:
  * The remap_struct function in sa_common.c has an out-of-bounds
    read during a memmove call [CVE-2018-19416, bsc#1117001]
  * The remap_struct function in sa_common.c has an out-of-bounds read
    during a memset call [CVE-2018-19517, bsc#1117260]
  * Added patch sysstat-12.0.2-CVE-2018-19416-and-CVE-2018-19517.patch
* Mon Nov 12 2018 Martin Pluskal <mpluskal@suse.com>
- Run tests during build
- Use explicit list of binaries in files section of spec file
* Tue Oct 16 2018 Tomáš Chvátal <tchvatal@suse.com>
- Up to 12.0.2: (fate#326576, bsc#1089883)
  * This version mainly includes bugfixes
- Dropped patches for SLE-12, fixed upstream:
  * sysstat-10.2.1-iostat-sar-util.patch
  * sysstat-10.2.1-sar-ifutil.patch
  * sysstat-10.2.6-fix-json-with-file-utc-time.patch
* Tue Aug 14 2018 tchvatal@suse.com
- Version update to 12.0.1:
  * sadf: SVG: Remove id tag from individual graphs. Use activities
    identification numbers for id tags.
  * sadf: SVG: Add new option "showtoc", which can be used to display
    the list of activities for which there are graphs ("table of
    contents").
  * sadf: SVG: Improve output for softnet activity: Add a discontinuity in
    graph when corresponding CPU is marked offline.
  * sadf: SVG: Improve function used to assess SVG canvas height.
  * sadf: SVG: Fix core dumped on buffers reallocation.
  * sar/sadf: Devices list management code refactoring.
  * sa_conv.c: Use write_all() function instead of write() to handle possible
    signal interruptions.
  * spec file updated: No longer create a debug package.
  * Remove many warnings from gcc v7/v8.
  * README file updated.
  * Manual pages updated.
* Tue Aug 14 2018 tchvatal@suse.com
- Update to 11.6.5:
  * sadf: SVG: Display graphs for swap utilization in packed mode.
  * sadf: SVG: Don't take into account activities with no graphs when
    calculating canvas height.
  * sadf: SVG: Don't insert a gap in SVG output if an activity is not
    displayed.
  * sadf: SVG: Fix possible negative value in graphs coordinates.
* Thu Jun 21 2018 tchvatal@suse.com
- Version update to 11.6.4:
  * The number of decimal places used by sysstat commands (sar, cifsiostat, iostat, mpstat and pidstat),
  * The network interfaces, block devices and filesystems for which statistics shall be displayed by sar or sadf.
* Fri Apr 27 2018 tchvatal@suse.com
- Version update to 11.6.3:
  * A possible crash related to the new binary format used by sar, which could
    happen when buffers needed to be reallocated to accomodate more devices
    added to the system,
  * The %%CPU value displayed by pidstat for processes using more than 100%%
    of a core.
* Thu Apr 26 2018 fcrozat@suse.com
- Remove Requires on update-desktop-files on subpackage, it is
  useless.
* Thu Nov  2 2017 mpluskal@suse.com
- Update to version 11.6.1
  * See provided CHANGES for detailed list of changes
- Refresh patches:
  * sysstat-8.0.4-pagesize.diff
  * sysstat-8.0.4-sysconfdir.diff
  * sysstat-8.1.6-sa1sa2lock.diff
- Drop no longer needed
  * sysstat-8.0.4-sysconfdir.diff
* Fri Mar 31 2017 tchvatal@suse.com
- Properly specify you want to be started by multi-user.target
  bsc#1031674
* Sun Feb 19 2017 tchvatal@suse.com
- Update to 11.4.3 release
  * check the CHANGES file for detailed informations, too long
- Refresh patches:
  * sysstat-8.0.4-sysconfdir.diff
  * sysstat-8.1.6-sa1sa2lock.diff
- Remove patch that was converted to sed:
  * sysstat-9.0.4-no-build-date.patch
* Tue May 24 2016 ro@suse.de
- skip libsensors on s390/s390x
* Mon Nov 16 2015 mpluskal@suse.com
- Update to 11.0.8
  * Fix possible NULL pointer dereference in SREALLOC macro (CID
    [#29706]).
  * sadc: Fix untrusted value used as argument (CID #29720).
  * Update librdsensors.a target in Makefile.
- Changes for 11.0.7
  * [Peter Schiffer]: Fix problem with pidstat output values > 100%%
    for %%CPU.
  * [Alexis Solanas]: Fix issue with iostat not showing the full
    device name.
  * CREDITS file updated.
* Wed Sep  9 2015 mpluskal@suse.com
- Update to 11.0.6
  * Check /proc/net/snmp format to collect ICMP statistics at
    their right positions.
  * ioconf.c: Fix several ressource leaks.
  * mpstat: Fix alignment output, really.
  * [Sampsa Kiiskinen]: Fix bug in isag.
  * iostat manual page updated.
  * CREDITS file updated.
* Mon Jun 22 2015 mpluskal@suse.com
- Update to 11.0.5
  * [Peter Schiffer]: Fixed and simplified some math expressions
    in pr_stats.c.
  * [Peter Schiffer]: ioconf.c: Check value of variable "major"
    read from file.
  * [Peter Schiffer]: ioconf.c: Use strncpy instead of strcpy.
  * cifsiostat: Fixed possible integer overflowed argument.
  * sar: Fixed untrusted loop bound.
* Sun May 17 2015 mpluskal@suse.com
- Update to 11.0.4
  * Makefile: sysstat init script may sometimes be called rc.sysstat.
    So use that name when needed.
  * pidstat: Don't stop if gtime and cgtime fields are unavailable.
  * Typos fixed in XSD document.
  * [Peter Schiffer]: Replace spaces with tabs in Makefile.in.
  * [Peter Schiffer]: Create appropriate directories in DESTDIR if
    missing.
  * [Peter Schiffer]: Fixed installation of systemd/cron files on
    systems w/o systemd.
  * [Peter Schiffer]: Don't look in weird places for programs during
    configuration.
  * [Peter Schiffer]: Portable way to detect 64 bit OS in configure
    script.
  * [Steve Kay]: Fix mpstat SCPU alignment output.
  * Makefile: Call chkconfig only if $(COPY_ONLY) is set to no.
  * sysstat(5) manual page updated.
  * NLS updated.
- Use scriplets for updating desktop files
- Update patches
* Fri Feb 20 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update dependecies
- Update to 11.0.3:
  * Prefer xz compression program when compressing sa data files
  * sadc: Fix possible race condition in signal handler code
  * Fix description of %%util in iostat and sar manual pages
  * Make sure that no crontabs are activated when configure's
    option --enable-copy-only is used.
- Dropped patches, fixed upstream:
  * sysstat-don-t-send-signal-to-init.patch
  * sysstat-fix-possible-race-in-signal-handler.patch
* Fri Jul 18 2014 tabraham@suse.com
- update to 11.0.0
  * [Cedric Marie]: pidstat now displays task scheduling priority and policy (-R option).
  * [Cedric Marie]: pidstat: Add option -G to filter processes by name.
  * pidstat: Update variables type to be consistent with recent 3.x kernels.
  * sadc/sar/sadf: The standard daily data files may now be named saYYYYMMDD instead of saDD. Option -D has been added to sar and sadc to tell them to write to data files under the name saYYYYMMDD.
  * sadc/sar/sadf: Take into account alternate locations for standard daily data files.
  * sa1 and sa2 scripts updated: Don't create a tree of directories any more if HISTORY is greater than 28. Use saYYYYMMDD data files instead.
  * sa1 and sa2 scripts now take into account two new variables: SA_DIR (directory where sa and sar files are located) and ZIP (compression program to use).
  * Make sysstat init script source the functions library.
  * Fix possible buffer overflow.
  * Small fix with sadc's option -S: It is now possible to enter several comma separated values.
  * Don't install crontabs when using systemd timer units.
  * Manual pages updated.
  * FAQ updated.
  * NLS updated. Galician and Hungarian translations added.
  * CREDITS file updated.
- removed sysstat-rename_nfsiostat.patch (deprecated)
- refreshed the other patches
* Mon Apr 28 2014 coolo@suse.com
- remove %%ghost in /var/run, see
  http://lists.opensuse.org/opensuse-packaging/2014-04/msg00046.html
* Mon Jan 27 2014 vcizek@suse.com
- update to 10.2.1
  * Added new --enable-copy-only option to configure script.
    This option may be useful when creating sysstat package to
    make sure that files are only copied to $DESTDIR and that
    no service is activated (eg. for distro using systemd).
  * pidstat: Add a new metric to pidstat I/O statistics:
    per-task block I/O delays.
  * Take $DESTDIR variable into account when installing sysstat
    service used by systemd.
  * sadf -H, sadf -j and sadf -x now also display the file
    creation time.
  * Use sizeof() instead of hardcoded size values.
  * pidstat manual page updated.
  * Cosmetic fixes.
  * NLS updated.
- rename nfsiostat to nfsiostat-sysstat because of a name collision
  with a binary from nfs-utils (bnc#814447)
  * added sysstat-rename_nfsiostat.patch
* Mon Nov  4 2013 vcizek@suse.com
- update to 10.2.0
  * This version mainly focuses on pidstat, with several bug fixes
    and the addition of a new option (-v) enabling the user to
    display the number of threads and file descriptors associated
    with tasks.
- refreshed some of the patches
- move the lib64 patching from %%prep (overwrites service unit on
  every quilt setup)
* Wed Oct 23 2013 p.drouand@gmail.com
- Drop sysvinit support
* Fri Nov  9 2012 vcizek@suse.com
- fixed two typos in spec related to service unit, which prevented
  succesful startup (bnc#783886)
- service unit included hardcoded /usr/lib, so patching
  sysstat.service to use correct libdir
* Tue Oct 16 2012 vcizek@suse.com
- increased the default number of days for how long will sysstat
  keep the log files (fate#313767)
* Thu May 17 2012 vcizek@suse.com
- update to 10.0.5
  * [Alain Chereau]: Options -g and -T added to iostat. These options
    enable the user to display statistics for groups of devices.
  * [Vitezslav Cizek]: sadc now overwrites its standard daily data
    file when this file is from a past month.
  - fixes bnc#758356
  * sadf: Change time format from HH-MM-SS to HH:MM:SS in the
    various reports displayed by sadf.
  * XSD document updated: Added a maxOccurs indicator for the timestamp element.
  * Added option --enable-collect-all to configure script. This
    option tells sadc to collect all possible activities, including optional ones.
  * [Peter Schiffer]: Set exit code to 0 for sa2 shell script.
  * NLS updated. Croatian translation added.
  * iostat and sadc manual pages updated.
  * FAQ updated.
  * CREDITS file updated.
* Mon Mar 12 2012 tabraham@novell.com
- update to 10.0.4
  * [Andrey Borzenkov]: Don't take virtual devices into account in
    sar -b results.
  * [Peter Schiffer]: iostat didn't display target device
    information when a symbolic link was specified as a parameter.
    This is now fixed.
  * The number of jiffies spent by a CPU in guest mode given by the
    corresponding counter in /proc/stat may be slightly different
    from that included in the user counter. Take this into account
    when calculating current time interval value.
  * configure script updated: Added --disable-stripping option.
    Using this option tells configure to NOT strip object files.
  * FAQ updated.
  * sa1 manual page updated.
  * NLS updated. Serbian translation added.
- drop sysstat-do-not-strip.patch (use new configure option
  - -disable-stripping instead)
* Wed Feb 15 2012 puzel@suse.com
- pass '-S ALL' to first run of sadc after boot to properly
  include disk and interrupt statistics in the reports (bnc#746517)
* Wed Nov 30 2011 puzel@suse.com
- update to sysstat-10.0.3
  * sadf: New output format added: JSON (JavaScript Object
    Notation). This format can be displayed with sadf's option -j.
  * [Jürgen Heinemann]: Fixed a bug in sadf XML output.
  * [Jürgen Heinemann]: Fixed several bugs in DTD and XSD
    documents.
  * [Petr Uzel]: Fixed random crash with iostat when called with
    option -N [NOVELL Bug#729130].
  * sadf manual page updated.
- drop sysstat-fix-iostat-crash.patch (merged upstream)
* Wed Nov  9 2011 puzel@suse.com
- add sysstat-fix-iostat-crash.patch (bnc#729130)
* Thu Oct 27 2011 puzel@suse.com
- Generate the reports before midnight and simplify the cron file
  (bnc#720609)
* Wed Oct 26 2011 lnussel@suse.de
- don't enable sysstat by default (bnc#725791)
- don't use /var/lock (bnc#725785)
* Mon Oct 17 2011 fcrozat@suse.com
- Add systemd service for sysstat (bnc#723858).
* Mon Sep 19 2011 puzel@suse.com
- update to sysstat-10.0.2
  - see /usr/share/doc/packages/sysstat/CHANGES
* Thu Aug 11 2011 puzel@novell.com
- enable boot.sysstat service on new installation (bnc#711574)
* Mon Jun 27 2011 puzel@novell.com
- update to sysstat-10.0.1
  - see /usr/share/doc/packages/sysstat/CHANGES for
    full list of changes
- update patches
- get rid of obsolete --disable-smp-race configure option
- use --enable-debug-info configure option
- install /var/lock/sa as ghost file
- use spec-cleaner
* Mon Mar  7 2011 puzel@novell.com
- make /etc/sysstat/sysstat config(noreplae) (bnc#674719)
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Wed Oct 20 2010 ro@suse.de
- update to 9.0.6.1
  * Because of a change in /proc/interrupts file format, mpstat
    was no longer counting the proper number of interrupts. This
    is now fixed.
  * iostat manual page updated.
  * NLS updated.
- update to 9.0.6
  * "sadf -x" now takes into account options -s and -e (which
    specify a starting and ending time) and also interval and
    count parameters [DEBIAN bug#546259].
  * Option -C added to sadf. Use it to tell sadf to display comments
    present in file (also works with XML format).
  * sar and sadf sometimes didn't handle COMMENT records properly.
    This is now fixed.
  * XML output (displayed by sadf -x) modified for kernel tables
    statistics.
  * XSD and DTD documents updated.
  * [Yibin Shen]: HZ variable was not explicitly set in sadc.c. This is now fixed.
  * [Lans Carstensen]: sargraph added (sargraph is a shell script used to make graphs
    based on sadf XML output).
  * sadf manual page updated.
  * FAQ updated.
  * NLS updated.
  * CREDITS file updated.
- update to 9.0.5
  * sysstat should now be able to pretty print device names whose
    minor numbers are greater than or equal to 256. (Tests have
    been made on a large 26TB RHEL5/PP Linux cluster.)
  * sadc manual page updated.
  * NLS updated.
  * FAQ updated.
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- Do not hardcode build dates, make build-compare happy
* Fri May 28 2010 puzel@novell.com
- add sysstat-do-not-strip.patch
* Wed Aug  5 2009 prusnak@suse.cz
- updated to 9.0.4
  * [Jonathan Kamens]: Fix double free/memory corruption bug
    with sadc.
  * [Jeroen Roovers]: Get entirely rid of implicit rule for
    libsyscom.a in Makefile to fix a problem with parallel
    execution.
  * sysstat.ioconf configuration file updated.
* Wed Jun 10 2009 prusnak@suse.cz
- merge some changes from package in server:monitoring project
* Fri May 29 2009 prusnak@suse.cz
- updated to 9.0.3
  * [Michael Blakeley]: Option -z added to iostat. This option
    tells iostat to omit output for any devices for which there
    was no activity during the sample period.
  * [Tomasz Pala]: Fix mpstat where interrupt values should be
    read as unsigned integers.
  * sar -n ALL didn't select IPv6 statistics. This is now fixed.
  * iostat, sar and mpstat manual pages updated.
  * sadf -x now displays file creation date.
  * XSD and DTD documents updated.
  * NLS updated. Latvian translation added.
  * CREDITS file updated.
  * Code cleaned.
- updated to 9.0.2
  * sadc can now collect partition statistics in addition to disk ones.
    Keywords XDISK and XALL have been added to -S option.
  * Fixed a memory corruption in pidstat and iostat. This corruption
    could happen when a list of comma-separated values following
    option -p was entered on the command line.
  * configure now takes into account a new variable named rcdir.
    This variable may be used to specify the directory where
    startup scripts will be installed.
  * The value of directory for installing documentation files
    can now be set with configure's --docdir option.
  * Fixed a small bug in activity.c file, where there was a
    missing semicolon between two fields.
  * sar and sadc manual pages updated.
  * NLS updated.
  * CREDITS file updated.
* Mon Mar  9 2009 prusnak@suse.cz
- updated to 9.0.1
  * Fix a crash with sar where a pointer was freed twice.
  * NLS updated.
  * sar manual page updated.
  * CREDITS file updated.
* Mon Mar  2 2009 prusnak@suse.cz
- updated to 9.0.0
  * Option -m added to sar. This option is intended to display
    power management statistics. At the present time, only
    CPU frequency statistics are available.
  * sadc updated: Option "-S POWER" tells sadc to collect power
    management statistics.
  * sadf command updated to take into account power management
    statistics.
  * [Mike Harvey]: No longer truncate the interval of time to
    32 bits, as this may cause some problems when displaying
    average values statistics on machines with hundreds of CPU.
  * read_uptime(): Cast values read from /proc/uptime to
    unsigned long long.
  * Fixed a small bug in sar where it didn't parse arguments
    properly when some options were entered in a specific order.
  * sadc and sar manual pages updated.
  * XSD and DTD documents updated.
  * FAQ updated.
  * NLS updated.
  * Code cleaned. Makefile cleaned.
* Fri Sep 26 2008 prusnak@suse.cz
- changed parameter "-d" to "-S ALL" in crontab to match the new syntax
* Mon Sep  8 2008 prusnak@suse.cz
- fixed german translation
* Tue Aug 19 2008 prusnak@suse.cz
- updated to 8.1.5:
  - changes too numerous to list (see CHANGES file)
- fix missing --boot parameter in init script [bnc#378874]
- fixed disc statistics logging [bnc#407004]
* Thu Jun 26 2008 werner@suse.de
- No patch for SuSE stuff
* Thu Jun 19 2008 werner@suse.de
- Add missing Provides to the init script
* Wed Apr  2 2008 prusnak@suse.cz
- do not remove log files when package is updated [bnc#371994]
* Tue Jan  8 2008 prusnak@suse.cz
- updated to 8.0.4:
  * Removed a 'packed' attribute in pidstat.h that generated
    a warning with gcc 4.1.1.
  * Take account of all memory zone types when calculating
    pgscank, pgscand and pgsteal displayed by sar -B.
  * XML Schema added. Useful with sadf option -x.
  * sadc and sadf manual pages updated.
  * NLS updated: Dutch translation added.
  * NLS updated: Brazilian Portuguese translation added.
  * NLS updated: Vietnamese translation added.
  * NLS updated: Kirghiz translation added.
  * NLS updated: Added a PO template file in nls directory.
    Makefile modified to enable PO files update.
  * sccsid string now also includes package name and version number.
  * Makefile updated: Startup links are named S01xxx instead of S03xxx
    to be consistent with chkconfig values.
  * Various spelling fixes.
  * CREDITS file updated.
* Tue Nov 20 2007 prusnak@suse.cz
- updated to 8.0.3
  * mpstat and sar didn't parse /proc/interrupts correctly when
    some CPUs had been disabled. This is now fixed.
  * fixed a bug in pidstat where a confusion between PID and TID
    could sometimes happen, resulting in erroneous statistics
    values being displayed.
  * iconfig script updated: Help for --enable-compress-manpg
    parameter is now available, help for --enable-install-cron
    parameter updated, added parameter cron_interval.
  * sa2 shell script can now compress sar data files using bzip2.
  * Makefile updated: Now also remove sysstat.crond.sample.in.
    Documentation is installed in $prefix/share/doc/ instead of
    $prefix/doc/ directory.
  * isag updated
  * FAQ updated
  * CREDITS file updated
  * sysstat's URL updated
* Tue Oct 30 2007 prusnak@suse.cz
- updated to 8.0.2
  * option -w added to pidstat. pidstat can now display task
    switching activity
  * fixed a memory leak in pidstat that was triggered when
    reading stats for threads
  * fixed a bug where device names were incorrectly displayed by
    sar -d or sar -dp
  * when using option -o, sar now saves by default all the
    statistics into the file, including interrupts and disks
    statistics (interrupts and disks statistics remain optional
    when using sadc)
* Tue Oct 16 2007 prusnak@suse.cz
- added boot.clock to Require-Start in initscript [#333793]
* Tue Oct  2 2007 prusnak@suse.cz
- update to 8.0.1
  * Option -t added to pistat. pidstat can now display stats for
    every thread (TID) of a process.
  * pidstat's option -T CHILD now reports global statistics for
    selected tasks and all their children (and not only for the
    children).
  * pidstat now reads VSZ and RSS values from /proc/#/stat instead
    of /proc/#/status.
  * Fixed a rare parallel make issue creating archive libsyscom.a
    [GENTOO bug #193208].
  * pidstat manual page updated.
  * SCCS identification string added to all commands.
  * NLS updated.
  * Code cleaned.
  * CREDITS file updated.
- altered pagesize.diff
* Tue Sep 25 2007 prusnak@suse.cz
- update to 8.0.0
  * WARNING: Daily data files format has changed, and is *not*
    compatible with the previous one! [0x216e]
  * pidstat command improved. It is now able to report CPU and
    page fault statistics for the child processes of a task.
  * Option -T added to pidstat. This option tells pidstat if
    statistics are to be reported for tasks (which is the default)
    or for their children.
  * Fixed a security flaw in sysstat startup script (CVE-2007-3852).
  * Removed super*, dquot* and rtsig* fields from sar -v.
    They were made obsolete in Linux kernels 2.6.
  * Fields file-sz and inode-sz from sar -v renamed in file-nr
    and inode-nr.
  * Added field pty-nr (number of pseudo-terminals) to sar -v.
  * Added field tcp-tw (number of sockets in TIME_WAIT state)
    to sar -n SOCK.
  * sar and sadf updated so that they can properly extract records
    (with their options -s and -e) from a file containing data for
    two consecutive days.
  * Added option "--enable-install-isag" to "configure" to enable
    the user to install isag script.
  * Fixed a typo in iconfig script: The user was unable to specify
    the crontab owner.
  * Manual pages updated
  * Sysstat DTD file updated
  * isag updated
* Tue Jul 10 2007 prusnak@suse.cz
- update to 7.1.6
  * new VM paging metrics added to sar
  * options -x and -X have been removed from sar, use pidstat instead
  * sar updated to avoid overflow when computing some average values
* Tue Jun 12 2007 prusnak@suse.cz
- updated to 7.1.5
- dropped obsolete patches
  * filelen.patch (included in update)
* Tue Jun  5 2007 prusnak@suse.cz
- fixed init-script and crontab files on 64bit archs [#280096]
* Wed May  2 2007 prusnak@suse.cz
- update to 7.1.4:
  * added new command "pidstat" aimed at displaying per-process statistics
  * added -N option to iostat
  - option enables the user to query any device-mapper devices for their
    registered device name
  * fixed a small memory leak in readp_uptime() function
  * stricter syntax checking for iostat
  * sar -dp now displays the device as "devM-N" (instead of "nodev") when it
    can't find its real name in sysstat.ioconf file
  * iostat -t now also takes into account the value of environment
    variable S_TIME_FORMAT
  * manual pages now take into account variables defined by "configure"
  * isag now takes into account variables defined by "configure"
  * "configure" now determines automatically whether workaround for SMP race
    is needed (SMP kernels 2.2.15 and older only)
* Tue Apr 17 2007 prusnak@suse.cz
- splitted isag utility to separate subpackage sysstat-isag
  * users will not be forced to install gnuplot (and X stuff) if
    they do not want to
* Tue Apr 17 2007 prusnak@suse.cz
- update to 7.1.3
  * fixed bug in hotplug cpu support
  * better support for keeping sar logfiles for more than one month
  * code cleaned
* Tue Mar 13 2007 prusnak@suse.cz
- update to 7.1.2
  * autoconf support
  * better hotplug CPU support
  - no longer assuming that CPU#0 can never be disabled
  * sar datafiles format changed to become more compact
* Thu Feb  8 2007 prusnak@suse.cz
- changed spec file to build with #norootforbuild
* Wed Feb  7 2007 prusnak@suse.cz
- update to 7.0.4
  * fixed incorrect NFS client and server statistics for sar
  * added hotplug CPU support to sar and mpstat
  * added iostat NFS statistics
- dropped obsoleted patches:
  * sysstat-6.0.2-hz.diff
* Thu Dec  7 2006 prusnak@suse.cz
- added procmail to Requires [#226503]
* Mon Aug  7 2006 ro@suse.de
- fix one more place with HZ usage
* Fri Jul 28 2006 olh@suse.de
- sysstat bootscript depends on boot.rootfsck, optional $local_fs (#181972)
* Tue Apr 25 2006 mjancar@suse.cz
- use sysconf(_SC_CLK_TCK) to get correct HZ (#168604)
* Fri Mar 24 2006 anicka@suse.cz
- fix bug in sysstat-6.0.2.diff [#155329]
- package file /usr/lib/sa/sa2
* Thu Jan 26 2006 mjancar@suse.cz
- prune old files (#136703)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 majncar@suse.cz
- update to 6.0.2
* Thu Oct 13 2005 mjancar@suse.cz
- update to 6.0.1
- split patches by subject
* Sat Apr  9 2005 aj@suse.de
- Compile with GCC4.
* Thu Feb 24 2005 mjancar@suse.cz
- remove .cron from the crontab filename (#64225)
* Fri Sep  3 2004 tcrhak@suse.cz
- update to 5.0.6
* Mon Aug  9 2004 tcrhak@suse.cz
- update to 5.0.5
* Wed Jun 30 2004 tcrhak@suse.cz
- changed isag data file mask according to sa file naming
  (patch mask, bug #41691)
* Tue Mar 30 2004 tcrhak@suse.cz
- fixed insecure tmp file handling in isag (bug #35103, patch isag)
- do not install crontab directly into /etc/cron.d, but create/remove
  symlink threre during start/stop in the init script (bug #33279)
- added rcsysstat
- fixed sa1 and sa2
* Wed Feb 18 2004 tcrhak@suse.cz
- update to version 5.0.1
* Fri Sep 12 2003 tcrhak@suse.cz
- fix for systems with more than 32 cpus and a lot of memory
  [bug #30561] patch bumper
* Wed Aug 20 2003 tcrhak@suse.cz
- added LSB comments to init script [bug #24541]
* Wed Jul 23 2003 tcrhak@suse.cz
- do not log running /usr/lib/sa/sa1 every 10 minutes [bug #27253]
* Sun Jun  1 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon Mar 10 2003 tcrhak@suse.cz
- added isag script and man page
- be more descriptive in an error message (patch msg)
* Thu Feb 27 2003 tcrhak@suse.cz
- require $local_fs for start in init script [bug #24400]
  (patch init)
* Mon Feb 17 2003 tcrhak@suse.cz
- updated to version 4.0.7
- moved helper binary and scripts
  back to /usr/lib [bug #21713]
* Fri Sep  6 2002 tcrhak@suse.cz
- bug #18901:
  - use proper libdir (lib/lib64) in cron, scripts and man pages
  - in /etc/init.d/sysstat: no option b, test exit
    status of sadc, remove lockfile and be verbose
* Tue Aug  6 2002 kukuk@suse.de
- Don't start programs in post-install
- Add PreRequiers for insserv and fillup
* Thu Feb  7 2002 tcrhak@suse.cz
- another %%{_libdir} fix
* Thu Jan 31 2002 tcrhak@suse.cz
- update to 4.0.3
- refined scripts sa1 and sa2 to handle lockfile safe
* Fri Jan 18 2002 tcrhak@suse.cz
- used macros %%{_lib} and %%{_libdir}
* Tue Dec 18 2001 tcrhak@suse.cz
- update to version 4.0.2
- fixed bug #12664
- added dependecy on gnuplot
- adapted spec to use fillup_and_insserv/insserv_cleanup staff
* Mon Aug 20 2001 adostal@suse.cz
- update to version 4.0.1
- update patch
* Tue May 15 2001 pblaha@suse.cz
- add file lock for scripts sa1 and sa2 for fix bug #7861
* Thu May  3 2001 pblaha@suse.cz
- use sa.%%Y_%%m_%%d format for sar command
* Sun Apr 15 2001 schwab@suse.de
- Use getpagesize() instead of PAGE_SHIFT.
* Thu Apr 12 2001 pblaha@suse.cz
- update on 4.0.0
* Wed Mar 21 2001 schwab@suse.de
- Use getpagesize() instead of PAGE_SHIFT.
* Thu Dec  7 2000 nadvornik@suse.de
- fixed init script
* Wed Dec  6 2000 nadvornik@suse.cz
- fixed sa1 and sa2 scripts
- fixed cron files
* Sat Dec  2 2000 smid@suse.cz
- new version 3.3.2
* Thu Oct 19 2000 smid@suse.cz
- new version 3.3.1
* Thu Jun  8 2000 nadvornik@suse.cz
- fixed clean section
* Fri May  5 2000 smid@suse.cz
- upgrade to 3.2
- buildroot added
* Tue Jan 18 2000 nashif@suse.de
- Initial release (Version 2.2)
